var searchData=
[
  ['design_20rules_0',['Design Rules',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md7',1,'']]],
  ['dictionaries_1',['Customizing Jieba Dictionaries',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md11',1,'']]],
  ['dictionary_2',['Dictionary',['../dir_68267d1309a1af8e8297ef4c3efbcdba.html#autotoc_md2',1,'']]],
  ['distro_20maintainers_3',['Packaging for Distro Maintainers',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md14',1,'']]]
];
